@@ -15,9 +15,15 @@
 
 
 """WebElement implementation."""
+import os
+import zipfile
+from StringIO import StringIO
+import base64
+
+
 from command import Command
-from selenium.webdriver.common.by import By
 from selenium.common.exceptions import NoSuchAttributeException
+from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import Keys
 
 
@@ -113,7 +119,7 @@ class WebElement(object):
     def find_elements_by_xpath(self, xpath):
         """Finds elements within the elements by xpath."""
         return self.find_elements(by=By.XPATH, value=xpath)
-    
+
     def find_element_by_class_name(self, name):
         """Finds an element by their class name."""
         return self.find_element(by=By.CLASS_NAME, value=name)
@@ -125,13 +131,17 @@ class WebElement(object):
     def find_element_by_css_selector(self, css_selector):
         """Find and return an element by CSS selector."""
         return self.find_element(by=By.CSS_SELECTOR, value=css_selector)
-    
+
     def find_elements_by_css_selector(self, css_selector):
         """Find and return list of multiple elements by CSS selector."""
         return self.find_elements(by=By.CSS_SELECTOR, value=css_selector)
 
     def send_keys(self, *value):
         """Simulates typing into the element."""
+        local_file = LocalFileDetector.is_local_file(*value)
+        if local_file is not None:
+            value = self._upload(local_file)
+
         typing = []
         for val in value:
             if isinstance(val, Keys):
@@ -142,7 +152,7 @@ class WebElement(object):
                     typing.append(val[i])
             else:
                 for i in range(len(val)):
-                    typing.append(val[i]) 
+                    typing.append(val[i])
         self._execute(Command.SEND_KEYS_TO_ELEMENT, {'value': typing})
 
     # RenderedWebElement Items
@@ -200,3 +210,36 @@ class WebElement(object):
     def find_elements(self, by=By.ID, value=None):
         return self._execute(Command.FIND_CHILD_ELEMENTS,
                              {"using": by, "value": value})['value']
+
+    def _upload(self, filename):
+        fp = StringIO()
+        zipped = zipfile.ZipFile(fp, 'w', zipfile.ZIP_DEFLATED)
+        zipped.write(filename)
+        zipped.close()
+        return self._execute(Command.UPLOAD_FILE, {'file': base64.encodestring(fp.getvalue())})['value']
+
+class LocalFileDetector(object):
+
+    @classmethod
+    def is_local_file(cls, *keys):
+        file_path = ''
+        typing = []
+        for val in keys:
+            if isinstance(val, Keys):
+                typing.append(val)
+            elif isinstance(val, int):
+                val = str(val)
+                for i in range(len(val)):
+                    typing.append(val[i])
+            else:
+                for i in range(len(val)):
+                    typing.append(val[i])
+        file_path = ''.join(typing)
+
+        if file_path is '':
+            return None
+
+        if os.path.exists(file_path):
+            return file_path
+        else:
+            return None
